%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%                                                                         %
% LNSE1d:      Solve the EVP pertinent to the 1d LNSE                     %
%                                                                         %
%                       (c) 2014 vt_productions                           %
%                                                                         %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all;

% Set number of discretization nodes in the y spatial direction
Ny=128;

% Set flow and parameters
flow = 'SL';

% Set grid and collocation derivative matrices
[xgl,d1y,d2y] = set_chebyshev_derivative_matrices(Ny);

% If necessary, map the domain
[ y, d1y, d2y ] = mapping ( flow, xgl, d1y, d2y );

% Define the base flow
switch flow
    case 'PPF'
         
         [ U, Uy, Uyy ] = baseFlow_PPF( y );
         
         % Th94 test case:  OMEGAR=0.23752649, OMEGAI=0.00373967
         Re = 10000;
         alpha = 1;
         beta = 0;
    
         % CHQZ test case: OMEGAR=0.24989154, OMEGAI=0.00223497
         % Re=7500;
         % alpha=1;
         % beta=1;
    
    case 'SL'
    
         [ U, Uy, Uyy ] = baseFlow_SL( y );
    
         % Michalke case
         Re=1e5;
         alpha=0.4446;
         beta=0;
    
    otherwise
        
         disp('Flow Case Not Implemented')
         pause
end

% Form the EVP
[ A, B ] = form_LNSE1d(Re, alpha,  Ny, U, Uy, d1y, d2y);

% Impose BCs
[ A, B ] = impose_BCs_LNSE1d( Ny, A, B );

% Solve the EVP using the QZ algorithm (full spectrum computation)
[V,lambda]=eig(A,B,'qz');

% Extract the eigenvalues
omegar=real(diag(lambda));
omegai=imag(diag(lambda));

% Plot the results
plot_LNSE1d(flow,1i*lambda,V,y,Re,alpha,beta)

% END