function [ der1y, der2y ] = calculate_ddy( Ny, d1y, d2y, y );
%
%CALCULATE_DDY: Use Chebyshev spectral collocation to compute 
%               1st and 2nd derivatives of a non-periodic function
% INPUTS
% Ny:   number of (mapped) Chebyshev collocation nodes 
%       discretizing the non-periodic domain (not passed as an argument)
% y:    periodic function defined on the (mapped) domain
% d1y:  1st Chebyshev collocation derivative matrix, 
%       modified by the mapping transformation
% d2y:  2nd Chebyshev collocation derivative matrix, 
%       modified by the mapping transformation
% OUTPUTS
% der1y:1st derivative of the non-periodic function x
% der2y:2nd derivative of the non-periodic function x


for j =1:Ny+1
    der1y(j)=dot(d1y(j,:),y);
    der2y(j)=dot(d2y(j,:),y);
end

return