function [ A, B ] = form_LNSE1d(Re, alpha,  Ny, U, Uy, d1y, d2y);
%
% FORM_LNSE1D: Form the Linearized Navier-Stokes Equations in 1D

% INPUTS
% Re, alpha:  Reynolds number and streamwise wavenumber
% Ny:         number of Chebyshev collocation nodes
% d1y, d2y:   Chebyshev Gauss Lobatto collocation derivative matrices
% U, Uy:      Streamwise baseflow velocity and its 1st derivative 

% OUTPUTS
% A:          LHS of the discretized LNSE operator in 1D
% B:          RHS of the discretized LNSE operator in 1D,
%             including an artificial compressibility parameter: 
%             epsilon=1e-8

% (c) 2014 vt_productions

epsilon = 1e-8;

Lop=1/Re*d2y-alpha^2/Re*eye(Ny+1,Ny+1)-1i*alpha*diag(U);

A11=Lop;
A12=-diag(Uy);
A13=-1i*alpha*eye(Ny+1,Ny+1); 
A1=horzcat(A11,A12,A13);

A21=zeros(Ny+1);
A22=Lop;
A23=-d1y;
A2=horzcat(A21,A22,A23);

A31=1i*alpha*eye(Ny+1,Ny+1);
A32=d1y;
A33=zeros(Ny+1);
A3=horzcat(A31,A32,A33);

A=vertcat(A1,A2,A3);

B11=eye(Ny+1);
B12=zeros(Ny+1);
B13=zeros(Ny+1);
B1=horzcat(B11,B12,B13);

B21=zeros(Ny+1);
B22=eye(Ny+1);
B23=zeros(Ny+1);
B2=horzcat(B21,B22,B23);

B31=zeros(Ny+1);
B32=zeros(Ny+1);
%B33=epsilon*eye(Ny+1);
B33=zeros(Ny+1);
B3=horzcat(B31,B32,B33);

B=vertcat(B1,B2,B3);

return