function [ y, d1, d2 ] = mapping ( flow_case, y, d1, d2 )
%
% mapping:         Map the [-1,1] CGL domain onto [-y_inf,y_inf]. 
%                  Compute the metric of the transformation and modify
%                  first and second derivative matrices accordingly.
%                  Plane Poiseuille flow and tanh(y) profiles implemented
%
% INPUT
% flow_case:       PPF and free shear layer (SL) model 
%
% INPUTS/OUTPUTS
% y, d1, d2:       CGL grid and collocation derivative matrices
%
% (c) 2014 vt_productions
%

metric(:,2) = zeros(size(y));

switch flow_case 
   
   case 'PPF'
        eta = y;
        metric(:,1) = ones(size(y));
        metric(:,2) = zeros(size(y));
   
   case 'SL'   
        len = 10;
        s_inf = 15;
        s = (len/s_inf)^2;
        for i=1:length(y)
            eta(i) = -len*y(i)/sqrt(1.+s-y(i)^2);
%       eta(i) = len*sinh(-s*y(i))/sinh(s);
        end
        for i=1:length(y)
            metric(i,1) = -sqrt(1.+s)*len^2/(len^2+eta(i)^2)^(3./2);
            metric(i,2) = 3*len^2*sqrt(1.+s)*eta(i)/(len^2+eta(i)^2)^(5./2);
%       metric(i,1) = -(1./len/s)*sinh(s)/sqrt(1.+(sinh(s)*eta(i)/len)^2);
%       metric(i,2) = (1./len^3/s)*eta(i)*sinh(s)^3/sqrt(1.+(sinh(s)*eta(i)/len)^2)^3;
        end
        
    otherwise
        disp('Flow Case Not Implemented')
        pause
end
     
y = eta;
for i=1:length(y)
    d1(i,:) = metric(i,1) * d1(i,:);
    d2(i,:) = metric(i,1)^2 * d2(i,:) + metric(i,2) * d1(i,:);
end
%d2 = d1*d1;
    
end