function[xgl, d1y, d2y] = set_chebyshev_derivative_matrices(Ny);
%
% SET_CHEBYSHEV_DERIVATIVE_MATRICES: Define matrices for 
%       Chebyshev spectral collocation differentiation
% INPUTS
% Ny:   number of Chebyshev Gauss-Lobatto collocation nodes
%
% OUTPUTS
% xgl:  Chebyshev Gauss-Lobatto points
% d1y:  1st CGL collocation derivative matrix
% d2y:  2nd CGL collocation derivative matrix
%
% (c) 2014 vt_productions

for j=0:Ny
    jj=j+1;
    xgl(jj)=cos(j*pi/Ny);
end

for j=0:Ny
    jj=j+1;
    if(j==0 | j==Ny )
        cj=2.;
    else
        cj=1.;
    end
    for k=0:Ny
        kk=k+1;
        if(k==0 | k==Ny )
            ck=2.;
        else
            ck=1.;
        end
        if(j~=k)
            d1y(jj,kk)=(cj/ck)*(-1)^(j+k)/(xgl(jj)-xgl(kk));
        end
    end
end
for j=1:Ny-1
    jj=j+1;
    d1y(jj,jj)=-xgl(jj)/(2.*(1.-xgl(jj)^2));
end
d1y(1,1)=(2.*Ny^2+1.)/6.;
d1y(Ny+1,Ny+1)=-d1y(1,1);

d2y = d1y*d1y;

return